@@ -1,18 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "9e86d6537e75b6be0bedf551ec0f81341e965cf0",
-  "branchName": "release-client-6.1.x",
-  "buildTime": "2024-08-22 09:14:57 GMT",
-  "buildVersion": "1.0.1230",
+  "commitId": "0a2eed962563fd38d31224853f0976a1919de583",
+  "branchName": "release-client-6.x",
+  "buildTime": "2024-09-12 09:22:30 GMT",
+  "buildVersion": "1.0.976",
   "css": [
-    "@zoom/client-calendar-desktop/static/css/chunk-vendors.49e8f34d.css",
-    "@zoom/client-calendar-desktop/static/css/app.8024bba5.css"
+    "@zoom/client-scheduler/static/css/chunk-vendors.b08a77b8.css",
+    "@zoom/client-scheduler/static/css/index.60f74ba0.css"
   ],
   "js": [
-    "@zoom/client-calendar-desktop/static/js/chunk-vendors.775d7f30.js",
-    "@zoom/client-calendar-desktop/static/js/app.d14d52d5.js"
+    "@zoom/client-scheduler/chunk-vendors.27b5c1e6ded2cb8fd048.js",
+    "@zoom/client-scheduler/index.27b5c1e6ded2cb8fd048.js"
   ],
-  "key": "@zoom/client-calendar-desktop"
+  "key": "clientSchedulerResource"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
